# Aineko

Aineko is a Python framework for building data applications.

With Aineko, you seamlessly bring data into any product and iterate quickly. Whether you're an individual developer or part of a larger team, Aineko helps you rapidly build scalable, maintainable, and fast data applications.

Under the hood, Aineko automatically configures tooling needed for production-ready data apps, like message brokers, distributed compute, and more. This allows you to focus on building your application instead of spending time with configuration and infrastructure.

## Documentation

For full documentation visit: [Aineko Documentation](https://docs.aineko.dev/)

## Quickstart

Get started with Aineko in minutes by following [this tutorial](https://docs.aineko.dev/0.2/quickstart/)!

## Examples

To see some examples of Aineko in action visit [here](https://docs.aineko.dev/0.2/examples/aineko-dream/)

- [Aineko Dream](https://github.com/aineko-dev/aineko-dream)
- More coming soon...

## Contributing

If you're interested in contributing to Aineko, follow this [guide](https://docs.aineko.dev/dev/contributing/)
